﻿local recruitment = LibStub("AceAddon-3.0"):NewAddon("Recruitment")
local L = LibStub("AceLocale-3.0"):GetLocale("Recruitment", true)
local rcr = recruitment
rcr.frame = CreateFrame("Frame")

function rcr:msg(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg)
end

local defaults = {
  profile = {
    enabled = true,
		autojoin = true,
		timebetweenads = 5,
		addrandomnumber = true,
		autorandomnumber = true,
		randomnumberrange = 5,
		disablewhenafk = true,
		disablewhendnd = true,
		manualguildname = nil,
		hashint = false,
		overwritebuttonactive = true,
		ads = {},
		guildname = nil,
		currentguildname = nil,
		sameguild = false,
		isinguild = false,
		charname = nil,
  }
}

function rcr:iscity()
	local zones = {
		L["CityDarnassus"],
		L["CityIronforge"],
		L["CityOrgrimmar"],
		L["CitySilvermoonCity"],
		L["CityStormwindCity"],
		L["CityTheExodar"],
		L["CityThunderBluff"],
		L["CityUndercity"]
	}
	local zonename = GetZoneText()
	for i, v in ipairs(zones) do
		if zonename == v then
			return true
		end
	end
	return false
end

function rcr:getguildname()
	local guildinfo = GetGuildInfo("player")
	self.db.profile.sameguild = false
	self.db.profile.isinguild = false
	if IsInGuild() and guildinfo then
		self.db.profile.isinguild = true
		if not self.db.profile.guildname then
			self.db.profile.guildname = guildinfo
		end
		self.db.profile.currentguildname = guildinfo
		if self.db.profile.guildname == self.db.profile.currentguildname then
			self.db.profile.sameguild = true
		end
	elseif not IsInGuild() then
		if self.db.profile.manualguildname and not self.db.profile.guildname then
			self.db.profile.guildname = self.db.profile.manualguildname
		end
		self.db.profile.currentguildname = self.db.profile.manualguildname
		if self.db.profile.guildname == self.db.profile.currentguildname then
			self.db.profile.sameguild = true
		end
	end
end

function rcr.events(self, event, ...)
	rcr:msg("event: " .. event)
	if event == "CHAT_MSG_CHANNEL_NOTICE" then
		local channeljoined, _, _, _, _, _, _, _, channelname = ...
		if channeljoined == "YOU_JOINED" and string.match(channelname, L["GuildRecruitment"]) then
		end
	elseif event == "PLAYER_GUILD_UPDATE" or event == "GUILD_ROSTER_UPDATE" then
		rcr:getguildname()
	elseif event == "ZONE_CHANGED_NEW_AREA" then
		if rcr:iscity() then
		end
	end
end

rcr.frame:SetScript("OnEvent", rcr.events)

function rcr:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("recruitmentdb", defaults, true)
	self.db.profile.charname = UnitName("player")
	local options = {
		name = "Recruitment",
		handler = recruitment,
		type = "group",
		childGroups = "tab",
		args = {
			header = {
				order = 10,
				type = "description",
				name = L["Notes"],
				image = "Interface\\Icons\\Achievement_GuildPerk_EverybodysFriend",
				imageWidth = 32,
				imageHeight = 32,
			},
			enabled = {
				order = 20,
				type = "toggle",
				name = L["Enabled"],
				desc = L["EnabledDesc"],
				get = function() return self.db.profile.enabled end,
				set = function(info, value)
					self.db.profile.enabled = value
					if value then
						rcr:Enable()
					else
						rcr:Disable()
					end
				end,
			},
			generalsettings = {
				order = 30,
				type = "group",
				name = L["GeneralSettings"],
				desc = L["GeneralSettingsHeadline"],
				args = {
					autojoin = {
						order = 10,
						type = "toggle",
						name = L["AutoJoin"],
						desc = L["AutoJoinDesc"],
						width = "full",
						get = function() return self.db.profile.autojoin end,
						set = function(info, value) self.db.profile.autojoin = value end,
					},
					interval = {
						order = 20,
						type = "range",
						name = L["Interval"],
						desc = L["IntervalDesc1"] .. "\n\n" .. L["IntervalDesc2"],
						width = "full",
						min = 1,
						max = 60,
						step = 1,
						get = function() return self.db.profile.timebetweenads end,
						set = function(info, value) self.db.profile.timebetweenads = value end,
					},
					addrandomnumber = {
						order = 30,
						type = "toggle",
						name = L["RandomNumber"],
						desc = L["RandomNumberDesc1"] .. "\n\n" .. L["RandomNumberDesc2"],
						width = "full",
						get = function() return self.db.profile.addrandomnumber end,
						set = function(info, value) self.db.profile.addrandomnumber = value end,
					},
					autorandomnumber = {
						order = 40,
						type = "toggle",
						name = L["AutoRandomNumber"],
						desc = L["AutoRandomNumberDesc1"] .. "\n\n" .. L["AutoRandomNumberDesc2"] .. "\n\n" .. L["AutoRandomNumberDesc3"],
						width = "full",
						disabled = function() return not self.db.profile.addrandomnumber end,
						get = function() return self.db.profile.autorandomnumber end,
						set = function(info, value) self.db.profile.autorandomnumber = value end,
					},
					manualrandomnumber = {
						order = 50,
						type = "range",
						name = L["ManualRandomNumber"],
						desc = L["ManualRandomNumberDesc1"] .. "\n\n" .. L["ManualRandomNumberDesc2"],
						width = "full",
						disabled = function() return not self.db.profile.addrandomnumber or self.db.profile.autorandomnumber end,
						min = 1,
						max = 60,
						step = 1,
						get = function() return self.db.profile.randomnumberrange end,
						set = function(info, value) self.db.profile.randomnumberrange = value end,
					},
					disablewhenafk = {
						order = 60,
						type = "toggle",
						name = L["DisableWhenAFK"],
						desc = L["DisableWhenAFKDesc1"] .. "\n\n" .. L["DisableWhenAFKDesc2"],
						width = "full",
						get = function() return self.db.profile.disablewhenafk end,
						set = function(info, value) self.db.profile.disablewhenafk = value end,
					},
					disablewhendnd = {
						order = 70,
						type = "toggle",
						name = L["DisableWhenDND"],
						desc = L["DisableWhenDNDDesc1"] .. "\n\n" .. L["DisableWhenDNDDesc2"],
						width = "full",
						get = function() return self.db.profile.disablewhendnd end,
						set = function(info, value) self.db.profile.disablewhendnd = value end,
					},
				},
			},
			ads = {
				order = 40,
				type = "group",
				name = L["Ads"],
				desc = L["AdsHeadline"],
				args = {
					hintheader = {
						order = 10,
						type = "header",
						name = L["AdsHint"],
						hidden = function() return not self.db.profile.hashint end,
					},
					hint = {
						order = 20,
						type = "description",
						name = function()
							local hint = ""
							if not self.db.profile.sameguild then
								if self.db.profile.isinguild then
									hint = hint .. string.gsub(L["AdsHintDifferentGuild"], "%%p", self.db:GetCurrentProfile())
									hint = string.gsub(hint, "%%g", self.db.profile.guildname)
									hint = string.gsub(hint, "%%c", self.db.profile.charname) .. "\n\n" .. string.gsub(L["AdsHintDifferentGuildOverwrite"], "%%g", self.db.profile.currentguildname)
									self.db.profile.hashint = true
									self.db.profile.overwritebuttonactive = true
								end
							end
							return hint
						end,
						hidden = function() return not self.db.profile.hashint end,
					},
					overwriteguildname = {
						order = 22,
						type = "execute",
						name = L["Overwrite"],
						desc = function()
							local overwrite = string.gsub(L["OverwriteDesc1"], "%%og", self.db.profile.guildname)
							overwrite = string.gsub(overwrite, "%%cg", self.db.profile.currentguildname) .. "\n\n" .. L["OverwriteDesc2"]
							return overwrite
						end,
						func = function()
							self.db.profile.guildname = self:getguildname()
							self.db.profile.currentguildname = self.db.profile.guildname
							self.db.profile.overwritebuttonactive = false
							self.db.profile.hashint = false
						end,
						hidden = function() return not self.db.profile.overwritebuttonactive end,
					},
					hintfooter = {
						order = 23,
						type = "header",
						name = "",
						hidden = function() return not self.db.profile.hashint end,
					},
					manualguildnamepre = {
						order = 24,
						type = "description",
						name = "\n",
						hidden = function() return not self.db.profile.hashint end,
					},
					manualguildname = {
						order = 25,
						type = "input",
						name = L["AdsHintManualGuildName"],
						desc = L["AdsHintManualGuildNameDesc"],
						width = "full",
						hidden = function() local _, _, isinguild = self:getguildname() if isinguild or not self.db.profile.hashint then return true end end,
						get = function() return self.db.profile.manualguildname end,
						set = function(info, value) self.db.profile.manualguildname = value end,
					},
					textbox = {
						order = 40,
						type = "input",
						name = L["Ads"],
						desc = L["AdsDesc"],
						width = "full",
						multiline = true,
						get = function() return self.db.profile.ads end,
						set = function(info, value) self.db.profile.ads = value end,
					},
				},
			},
		},
	}
	options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Recruitment", options, nil)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Recruitment")
end

function rcr:OnEnable()
	rcr.frame:RegisterEvent("CHAT_MSG_ADDON")
	rcr.frame:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	rcr.frame:RegisterEvent("CHAT_MSG_CHANNEL_NOTICE")
	rcr.frame:RegisterEvent("PLAYER_GUILD_UPDATE")
	rcr.frame:RegisterEvent("GUILD_ROSTER_UPDATE")
	local guildname, sameguild = self:getguildname()
	if not sameguild then
		rcr:Disable()
	end
end

function rcr:OnDisable()
	rcr.frame:UnregisterAllEvents()
end